"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.json2jsonl = exports.Json2JsonL = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const constants_1 = require("../constants");
class Json2JsonL {
    getGruntConfig() {
        return {
            json2jsonl: {
                convert_json_loader_files_to_jsonl: {
                    src: [
                        path_1.default.join(constants_1.BUILD_DIR, 'prices.json'),
                        path_1.default.join(constants_1.BUILD_DIR, 'nodes.json'),
                        path_1.default.join(constants_1.BUILD_DIR, 'products.json'),
                        path_1.default.join(constants_1.BUILD_DIR, 'inventory.json'),
                        path_1.default.join(constants_1.BUILD_DIR, 'prod-assoc.json'),
                    ],
                    dest: path_1.default.join(constants_1.BUILD_DIR),
                    ext: '.jsonl',
                },
            },
        };
    }
    registerTasks(grunt) {
        grunt.registerMultiTask('json2jsonl', function () {
            json2jsonl(grunt, this);
        });
    }
}
exports.Json2JsonL = Json2JsonL;
function json2jsonl(grunt, grunt_this) {
    const convertFile = (src, target) => {
        const nodeJson = fs_1.default.readFileSync(src, 'utf8');
        const nodeJsonObj = JSON.parse(nodeJson);
        grunt.log.writeln(`Process ${nodeJsonObj.length} ${nodeJsonObj.length > 1 ? 'objects' : 'object'} into ${nodeJsonObj.length} jsonl ${nodeJsonObj.length > 1 ? 'lines' : 'line'}`);
        const nodeJsonLines = nodeJsonObj.map((line) => JSON.stringify(line)).join('\n');
        fs_1.default.writeFileSync(target, nodeJsonLines);
        grunt.log.writeln(`Wrote ${target}`);
    };
    try {
        grunt_this.files.forEach(function (file) {
            grunt.log.writeln('Processing ' + file.src.length + ' files.');
            file.src.forEach((srcFile) => {
                const filename = path_1.default.parse(srcFile).base;
                const src = path_1.default.resolve(srcFile);
                const extension = file.ext || '.jsonl';
                const target = path_1.default.resolve(file.dest, filename.replace(/\.json$/, extension));
                grunt.log.writeln('Processing ' + src + ' to ' + target);
                convertFile(src, target);
            });
        });
    }
    catch (e) {
        grunt.log.writeln('Exception: ' + e);
    }
}
exports.json2jsonl = json2jsonl;
