"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.jsonl2json = exports.JsonL2Json = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const constants_1 = require("../constants");
class JsonL2Json {
    getGruntConfig() {
        return {
            jsonl2json: {
                explode_s3_downloads: {
                    src: [path_1.default.join(constants_1.BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, '*.jsonl')],
                    dest: path_1.default.join(constants_1.BUILD_DIR, 'download/ih-uploads'),
                    ext: '.json',
                },
            },
        };
    }
    registerTasks(grunt) {
        grunt.registerMultiTask('jsonl2json', function () {
            jsonl2json(grunt, this);
        });
    }
}
exports.JsonL2Json = JsonL2Json;
function jsonl2json(grunt, grunt_this) {
    const convertFile = (srcFile, targetFolder, targetExtension) => {
        const srcFileName = path_1.default.parse(srcFile).base.replace(/.jsonl$/, '');
        const array = fs_1.default.readFileSync(srcFile).toString().split('\n');
        grunt.log.writeln(`Processing ${array.length} lines`);
        for (const [index, line] of array.entries()) {
            const file = targetFolder + '/' + srcFileName + (index + 1) + targetExtension;
            grunt.log.writeln(`Processing line ${index + 1} to ${file}`);
            fs_1.default.writeFileSync(file, JSON.stringify(JSON.parse(line), null, 2));
        }
    };
    try {
        grunt_this.files.forEach(function (file) {
            grunt.log.writeln('Processing ' + file.src.length + ' files.');
            file.src.forEach((srcFile) => {
                grunt.log.writeln(`Processing ${srcFile} to ${file.dest}`);
                convertFile(srcFile, file.dest, file.ext);
            });
        });
    }
    catch (e) {
        grunt.log.writeln('Exception: ' + e);
    }
}
exports.jsonl2json = jsonl2json;
