import fs from 'fs';
import path from 'path';
import { BUILD_DIR } from '../constants';
export class Json2JsonL {
    getGruntConfig() {
        return {
            json2jsonl: {
                convert_json_loader_files_to_jsonl: {
                    src: [
                        path.join(BUILD_DIR, 'prices.json'),
                        path.join(BUILD_DIR, 'nodes.json'),
                        path.join(BUILD_DIR, 'products.json'),
                        path.join(BUILD_DIR, 'inventory.json'),
                        path.join(BUILD_DIR, 'prod-assoc.json'),
                    ],
                    dest: path.join(BUILD_DIR),
                    ext: '.jsonl',
                },
            },
        };
    }
    registerTasks(grunt) {
        grunt.registerMultiTask('json2jsonl', function () {
            json2jsonl(grunt, this);
        });
    }
}
export function json2jsonl(grunt, grunt_this) {
    const convertFile = (src, target) => {
        const nodeJson = fs.readFileSync(src, 'utf8');
        const nodeJsonObj = JSON.parse(nodeJson);
        grunt.log.writeln(`Process ${nodeJsonObj.length} ${nodeJsonObj.length > 1 ? 'objects' : 'object'} into ${nodeJsonObj.length} jsonl ${nodeJsonObj.length > 1 ? 'lines' : 'line'}`);
        const nodeJsonLines = nodeJsonObj.map((line) => JSON.stringify(line)).join('\n');
        fs.writeFileSync(target, nodeJsonLines);
        grunt.log.writeln(`Wrote ${target}`);
    };
    try {
        grunt_this.files.forEach(function (file) {
            grunt.log.writeln('Processing ' + file.src.length + ' files.');
            file.src.forEach((srcFile) => {
                const filename = path.parse(srcFile).base;
                const src = path.resolve(srcFile);
                const extension = file.ext || '.jsonl';
                const target = path.resolve(file.dest, filename.replace(/\.json$/, extension));
                grunt.log.writeln('Processing ' + src + ' to ' + target);
                convertFile(src, target);
            });
        });
    }
    catch (e) {
        grunt.log.writeln('Exception: ' + e);
    }
}
